==> siag_3.1.22.orig.tar.gz: siag-3.1.22/xfiler/xfiler-ad.h <==
"Xfiler*doubleClickTime:		300",
"Xfiler*updateInterval:		10000",
"Xfiler.initGeometry:			400x350",
"Xfiler.file window.Geometry:	400x350",
"Xfiler*Command*cursor:			hand2",
"Xfiler*Scrollbar*background:	grey",
"Xfiler*SimpleMenu*cursor:		hand2",
"Xfiler*topbox.xLayout:		100%",
"Xfiler*topbox.yLayout:		30 30 30 100% 30",
"Xfiler*menubar.shadowWidth:		1",
"Xfiler*menubar.gridy:			0",
"Xfiler*menubox.orientation:		horizontal",
"Xfiler*menubox.borderWidth:		0",
"Xfiler*menubox.MenuButton.shadowWidth:	0",
"Xfiler*menubox.MenuButton.internalHeight:	6",
"Xfiler*menubox.SiagMenuButton.shadowWidth:	0",
"Xfiler*menubox.SiagMenuButton.internalHeight:	6",
"Xfiler*menubox.vSpace:			0",
"Xfiler*menubox.hSpace:			0",
"Xfiler*toolbar.shadowWidth:		1",
"Xfiler*toolbar.gridy:			1",
"Xfiler*toolbox.orientation:		horizontal",
"Xfiler*toolbox.borderWidth:		0",
"Xfiler*toolbox.Toggle.shadowWidth:	0",
"Xfiler*toolbox.Command.shadowWidth:	0",
"Xfiler*toolbox.vSpace:			0",
"Xfiler*toolbox.hSpace:			0",
"Xfiler*cmdform.gridy:			2",
"Xfiler*cmdform.defaultDistance:		2",
"Xfiler*cmdframe.top:			ChainTop",
"Xfiler*cmdframe.left:			ChainLeft",
"Xfiler*cmdframe.right:			ChainRight",
"Xfiler*cmdframe.bottom:			ChainBottom",
"Xfiler*cmdframe.shadowType:		Lowered",
"Xfiler*cmdtext.borderWidth:		0",
"Xfiler*cmdtext.width:			390",
"Xfiler*cmdtext.translations:		#override\\n\
	<Key>Return:			cmdline-run()\\n\
	<Key>Escape:			cmdline-cancel()\\n\
	<Key>Up:			cmdline-previous()\\n\
	Ctrl<Key>p:			cmdline-previous()\\n\
	<Key>Down:			cmdline-next()\\n\
	Ctrl<Key>n:			cmdline-next()",
"Xfiler*Box.handle.height:		28",
"Xfiler*Box.handle.label:",
"Xfiler*viewport.gridy:			3",
"Xfiler*viewport*font:			fixed",
"Xfiler*viewport.allowVert:		True",
"Xfiler*status.gridy:			4",
"Xfiler*status.shadowWidth:		2",
"Xfiler*status.label:",
"Xfiler*status.resize:			False",
"Xfiler*buttons*orientation:		horizontal",
"Xfiler*buttons*showGrip:		False",
"Xfiler*input:                           TRUE",
"Xfiler*toolbar_command.translations:	#override	\\n\
	<Enter>:	siag-highlight(1)\\n\
	<Leave>:	siag-unhighlight(0)",
"Xfiler*left arrow.shadowWidth:		0",
"Xfiler*left arrow.translations:	#override			\\n\
	<Enter>:		siag-highlight(1)		\\n\
	<Leave>:		siag-unhighlight(0)",
"Xfiler*right arrow.shadowWidth:		0",
"Xfiler*right arrow.translations:	#override			\\n\
	<Enter>:		siag-highlight(1)		\\n\
	<Leave>:		siag-unhighlight(0)",
"Xfiler*viewport.icon box*Toggle.foreground:	red",
"Xfiler*viewport.icon box*Toggle.shadowWidth: 	0",
"Xfiler*viewport.icon box*Command.shadowWidth: 	0",
"Xfiler*viewport.icon box*Label.justify:		Center",
"Xfiler*chmod.form.Form.Command.highlightThickness:0",
"Xfiler*boldFont:			-*-helvetica-bold-r-*-*-14-*",
"Xfiler*iconFont:			-*-helvetica-medium-r-*-*-12-*",
"Xfiler*labelFont:		-*-helvetica-medium-r-*-*-12-*",
"Xfiler*cellFont:		fixed",
"Xfiler*appIconWidth: 72",
"Xfiler*appIconHeight: 60",
"Xfiler*fileIconWidth: 48",
"Xfiler*fileIconHeight: 40",
"Xfiler*treeIconWidth: 48",
"Xfiler*treeIconHeight: 32",
"Xfiler*confirmDeletes: 		true",
"Xfiler*confirmDeleteFolder: 	true",
"Xfiler*confirmCopies: 		true",
"Xfiler*confirmMoves: 		true",
"Xfiler*confirmOverwrite:		false",
"Xfiler*confirmQuit:		false",
"Xfiler*echoActions:			false",
"Xfiler*showOwner: 		true",
"Xfiler*showDate: 		false",
"Xfiler*showPermissions: 		false",
"Xfiler*showLength: 		true",
"Xfiler*initialDisplayType:	 	Icons",
"Xfiler*defaultDisplayType: 		Icons",
"Xfiler*defaultSortType: 		SortByName",
"Xfiler*defaultEditor: 		xedplus",
"Xfiler*defaultViewer: 		xedplus",
"Xfiler*defaultTerm: 		xterm",
"Xfiler*Command.cursor: hand2",
"Xfiler*MenuButton.cursor: hand2",
"Xfiler*viewport.allowHoriz: false",
"Xfiler*viewport.forceBars: true",
"Xfiler*popup form*bitmap.borderWidth : 0",
"Xfiler*popup form.bitmap.top:		ChainTop",
"Xfiler*popup form.bitmap.left:		ChainLeft",
"Xfiler*popup form.bitmap.right:		ChainLeft",
"Xfiler*popup form.bitmap.bottom:	ChainTop",
"Xfiler*popup form*label.borderWidth : 0",
"Xfiler*popup form.label.top:		ChainTop",
"Xfiler*popup form.label.left:		ChainLeft",
"Xfiler*popup form.label.right:		ChainLeft",
"Xfiler*popup form.label.bottom:		ChainTop",
"Xfiler*button box.orientation: horizontal",
"Xfiler*button box.borderWidth: 0",
"Xfiler*button box.top:			ChainTop",
"Xfiler*button box.left:			ChainLeft",
"Xfiler*button box.right:		ChainLeft",
"Xfiler*button box.bottom:		ChainTop",
"Xfiler*viewport.borderWidth: 0",
"Xfiler*viewport.icon box*Label.borderWidth : 0",
"Xfiler*viewport.icon box.Command.borderWidth : 0",
"Xfiler*viewport.icon box.Form.borderWidth : 0",
"Xfiler*viewport.icon box*Toggle.borderWidth : 1",
"Xfiler*chmod*Label.borderWidth : 0",
"Xfiler*info*Label.borderWidth : 0",
"Xfiler*error*Label.borderWidth : 0",
"Xfiler*confirm*Label.borderWidth : 0",
"Xfiler*Text*translations : #override \\n <Key>Return: no-op() \\n <Key>Linefeed : no-op() \\n Ctrl<Key>J : no-op() \\n",

==> siag_3.5.1.orig.tar.gz: siag-3.5.1/xfiler/xfiler-ad.h <==
"Xfiler*doubleClickTime:		300",
"Xfiler*updateInterval:		10000",
"Xfiler.initGeometry:			500x400",
"Xfiler.file window.Geometry:	500x400",
"Xfiler*Command*cursor:			hand2",
"Xfiler*SimpleMenu*cursor:		hand2",
"Xfiler*topbox.xLayout:		100%",
"Xfiler*topbox.yLayout:		30 30 30 100% 30",
"Xfiler*menubar.shadowWidth:		1",
"Xfiler*menubar.gridy:			0",
"Xfiler*menubox.orientation:		horizontal",
"Xfiler*menubox.borderWidth:		0",
"Xfiler*menubox.NwsMenuButton.shadowWidth:	0",
"Xfiler*menubox.NwsMenuButton.internalHeight:	6",
"Xfiler*menubox.vSpace:			0",
"Xfiler*menubox.hSpace:			0",
"Xfiler*toolbar.shadowWidth:		1",
"Xfiler*toolbar.gridy:			1",
"Xfiler*toolbox.orientation:		horizontal",
"Xfiler*toolbox.borderWidth:		0",
"Xfiler*toolbox.Toggle.shadowWidth:	0",
"Xfiler*toolbox.Command.shadowWidth:	0",
"Xfiler*toolbox.vSpace:			0",
"Xfiler*toolbox.hSpace:			0",
"Xfiler*cmdform.gridy:			2",
"Xfiler*cmdform.defaultDistance:		2",
"Xfiler*cmdframe.top:			ChainTop",
"Xfiler*cmdframe.left:			ChainLeft",
"Xfiler*cmdframe.right:			ChainRight",
"Xfiler*cmdframe.bottom:			ChainBottom",
"Xfiler*cmdframe.shadowType:		Lowered",
"Xfiler*cmdtext.borderWidth:		0",
"Xfiler*cmdtext.width:			390",
"Xfiler*cmdtext.translations:		#override\\n\
	<Key>Return:			cmdline-run()\\n\
	<Key>Escape:			cmdline-cancel()\\n\
	<Key>Up:			cmdline-previous()\\n\
	Ctrl<Key>p:			cmdline-previous()\\n\
	~Shift<Key>Tab:			cmdline-tab(right)\\n\
	Shift<Key>Tab:			cmdline-tab(left)\\n\
	Ctrl<Key>c:			cmdline-copy()\\n\
	Ctrl<Key>x:			cmdline-cut()\\n\
	Ctrl<Key>v:			cmdline-paste()\\n\
	Ctrl<Key>q:			cmdline-quit()\\n\
	Ctrl<Key>w:			cmdline-close()\\n\
	Ctrl<Key>u:			cmdline-update()\\n\
	Ctrl<Key>n:			cmdline-new()\\n\
	<Key>Down:			cmdline-next()\\n\
	Ctrl<Key>n:			cmdline-next()",
"Xfiler*Box.handle.height:		28",
"Xfiler*Box.handle.label:",
"Xfiler*viewport.gridy:			3",
"Xfiler*viewport*font:			fixed",
"Xfiler*viewport.allowVert:		True",
"Xfiler*status.gridy:			4",
"Xfiler*status.shadowWidth:		2",
"Xfiler*status.label:",
"Xfiler*status.resize:			False",
"Xfiler*buttons*orientation:		horizontal",
"Xfiler*buttons*showGrip:		False",
"Xfiler*input:                           TRUE",
"Xfiler*toolbar_command.translations:	#override	\\n\
	<Enter>:	siag-highlight(1)\\n\
	<Leave>:	siag-unhighlight(0)",
"Xfiler*left arrow.shadowWidth:		0",
"Xfiler*left arrow.translations:	#override			\\n\
	<Enter>:		siag-highlight(1)		\\n\
	<Leave>:		siag-unhighlight(0)",
"Xfiler*right arrow.shadowWidth:		0",
"Xfiler*right arrow.translations:	#override			\\n\
	<Enter>:		siag-highlight(1)		\\n\
	<Leave>:		siag-unhighlight(0)",
"Xfiler*viewport.icon box*Toggle.foreground:	red",
"Xfiler*viewport.icon box*Toggle.shadowWidth: 	0",
"Xfiler*viewport.icon box*Command.shadowWidth: 	0",
"Xfiler*viewport.icon box*Label.justify:		Center",
"Xfiler*chmod.form.Form.Command.highlightThickness:0",
"Xfiler*boldFont:			-*-helvetica-bold-r-*-*-14-*",
"Xfiler*iconFont:			-*-helvetica-medium-r-*-*-12-*",
"Xfiler*labelFont:		-*-helvetica-medium-r-*-*-12-*",
"Xfiler*cellFont:		fixed",
"Xfiler*appIconWidth: 72",
"Xfiler*appIconHeight: 60",
"Xfiler*fileIconWidth: 48",
"Xfiler*fileIconHeight: 40",
"Xfiler*treeIconWidth: 48",
"Xfiler*treeIconHeight: 32",
"Xfiler*confirmDeletes: 		true",
"Xfiler*confirmDeleteFolder: 	true",
"Xfiler*confirmCopies: 		true",
"Xfiler*confirmMoves: 		true",
"Xfiler*confirmOverwrite:		false",
"Xfiler*confirmQuit:		false",
"Xfiler*echoActions:			false",
"Xfiler*showOwner: 		true",
"Xfiler*showDate: 		false",
"Xfiler*showPermissions: 		false",
"Xfiler*showLength: 		true",
"Xfiler*initialDisplayType:	 	Icons",
"Xfiler*defaultDisplayType: 		Icons",
"Xfiler*defaultSortType: 		SortByName",
"Xfiler*defaultEditor: 		xedplus",
"Xfiler*defaultViewer: 		xedplus",
"Xfiler*defaultTerm: 		xterm",
"Xfiler*Command.cursor: hand2",
"Xfiler*NwsMenuButton.cursor: hand2",
"Xfiler*viewport.allowHoriz: false",
"Xfiler*viewport.forceBars: true",
"Xfiler*popup form*bitmap.borderWidth : 0",
"Xfiler*popup form.bitmap.top:		ChainTop",
"Xfiler*popup form.bitmap.left:		ChainLeft",
"Xfiler*popup form.bitmap.right:		ChainLeft",
"Xfiler*popup form.bitmap.bottom:	ChainTop",
"Xfiler*popup form*label.borderWidth : 0",
"Xfiler*popup form.label.top:		ChainTop",
"Xfiler*popup form.label.left:		ChainLeft",
"Xfiler*popup form.label.right:		ChainLeft",
"Xfiler*popup form.label.bottom:		ChainTop",
"Xfiler*button box.orientation: horizontal",
"Xfiler*button box.borderWidth: 0",
"Xfiler*button box.top:			ChainTop",
"Xfiler*button box.left:			ChainLeft",
"Xfiler*button box.right:		ChainLeft",
"Xfiler*button box.bottom:		ChainTop",
"Xfiler*viewport.borderWidth: 0",
"Xfiler*viewport.icon box*Label.borderWidth : 0",
"Xfiler*viewport.icon box.Command.borderWidth : 0",
"Xfiler*viewport.icon box.Form.borderWidth : 0",
"Xfiler*viewport.icon box*Toggle.borderWidth : 1",
"Xfiler*chmod*Label.borderWidth : 0",
"Xfiler*info*Label.borderWidth : 0",
"Xfiler*error*Label.borderWidth : 0",
"Xfiler*confirm*Label.borderWidth : 0",
"Xfiler*Text*translations : #override \\n <Key>Return: no-op() \\n <Key>Linefeed : no-op() \\n Ctrl<Key>J : no-op() \\n",
